==> m2w-1.2.4.zip: plugin/weblog/word_press/word_press.rb <==
# coding: UTF-8

require 'xmlrpc_support/xmlrpc_parser'
require 'plugin/weblog/movable_type/movable_type'
require 'plugin/weblog/word_press/word_press_edit'
require 'plugin/weblog/word_press/word_press_post'

M2W_WEBLOG_WORDPRESS_DEFAULT_ENCODING = 'UTF-8'
M2W_WEBLOG_WORDPRESS_ATTACHMENT_ROOT_PATH = 'attrs'
M2W_WEBLOG_WORDPRESS_THUMBNAIL_ROOT_PATH = 'thumbs'
M2W_WEBLOG_WORDPRESS_XMLRPC_ENCODING = 'UTF-8'

#=WordPress のためのウェブログプラグイン
#
# 最初の著者:: トゥイー
# リポジトリ情報:: $Id$
# 著作権:: Copyright (C) Ownway.info, 2011. All rights reserved.
# ライセンス:: CPL(Common Public Licence)
class WordPress_WeblogPlugin < MovableType_WeblogPlugin

	def initialize(endpoint = M2W_WEBLOG_ENDPOINT, username = M2W_WEBLOG_USERNAME, password = M2W_WEBLOG_PASSWORD, encoding = M2W_WEBLOG_WORDPRESS_DEFAULT_ENCODING, attachment_root_path = M2W_WEBLOG_WORDPRESS_ATTACHMENT_ROOT_PATH, thumbnail_root_path = M2W_WEBLOG_WORDPRESS_THUMBNAIL_ROOT_PATH)
		super
	end

	def header_alias_for_post
		return {'keys' => 'mt_keywords', 'tags' => 'mt_keywords', 'cats' => M2W_WEBLOG_MT_CATEGORIES}
	end

	def client
		result = super
		result.set_parser(XMLRPCParser.new(M2W_WEBLOG_WORDPRESS_XMLRPC_ENCODING))
		return result
	end

	# 日付を文字列に直します。
	def get_date(date)
		date = date.clone
		date.gmtime
		return date
	end

	# 添付ファイルのデフォルトのパスを取得します。
	def get_attachment_default_filepath(postid, dateCreated, attachment_index, attachment_filename)
		return "#{@attachment_root_path}#{postid}_#{attachment_index}#{File.extname(attachment_filename)}"
	end

	# サムネイルのデフォルトのパスを取得します。
	def get_thumbnail_default_filepath(postid, dateCreated, attachment_index, attachment_filename)
		return "#{@thumbnail_root_path}#{postid}_#{attachment_index}#{File.extname(attachment_filename)}"
	end

	# ブログ記事投稿用のプラグインを取得します。
	def get_post_plugin()
		return WordPressPost_WeblogPlugin.new(self)
	end

	# ブログ記事編集用のプラグインを取得します。
	def get_edit_plugin()
		return WordPressEdit_WeblogPlugin.new(self)
	end

end

==> m2w-1.3.2.zip: plugin/weblog/word_press/word_press.rb <==
# coding: UTF-8

require 'xmlrpc_support/xmlrpc_parser'
require 'plugin/weblog/movable_type/movable_type'
require 'plugin/weblog/word_press/word_press_edit'
require 'plugin/weblog/word_press/word_press_post'

M2W_WEBLOG_WORDPRESS_DEFAULT_ENCODING = 'UTF-8'
M2W_WEBLOG_WORDPRESS_ATTACHMENT_ROOT_PATH = 'attrs'
M2W_WEBLOG_WORDPRESS_THUMBNAIL_ROOT_PATH = 'thumbs'
M2W_WEBLOG_WORDPRESS_XMLRPC_ENCODING = 'UTF-8'

#=WordPress のためのウェブログプラグイン
#
# 最初の著者:: トゥイー
# リポジトリ情報:: $Id: word_press.rb 685 2012-05-13 06:17:46Z toy_dev $
# 著作権:: Copyright (C) Ownway.info, 2011. All rights reserved.
# ライセンス:: CPL(Common Public Licence)
class WordPress_WeblogPlugin < MovableType_WeblogPlugin

	def initialize(
			endpoint = M2W_WEBLOG_ENDPOINT,
			username = M2W_WEBLOG_USERNAME,
			password = M2W_WEBLOG_PASSWORD,
			encoding = M2W_WEBLOG_WORDPRESS_DEFAULT_ENCODING,
			default_blogid = M2W_WEBLOG_DEFAULT_BLOGID,
			attachment_root_path = M2W_WEBLOG_WORDPRESS_ATTACHMENT_ROOT_PATH,
			thumbnail_root_path = M2W_WEBLOG_WORDPRESS_THUMBNAIL_ROOT_PATH)
		super
	end

	def header_alias_for_post
		return {'keys' => 'mt_keywords', 'tags' => 'mt_keywords', 'cats' => M2W_WEBLOG_MT_CATEGORIES}
	end

	def client
		result = super
		result.set_parser(XMLRPCParser.new(M2W_WEBLOG_WORDPRESS_XMLRPC_ENCODING))
		return result
	end

	# 日付を文字列に直します。
	def get_date(date)
		date = date.clone
		date.gmtime
		return date
	end

	# 添付ファイルのデフォルトのパスを取得します。
	def get_attachment_default_filepath(postid, dateCreated, attachment_index, attachment_filename)
		return "#{@attachment_root_path}#{postid}_#{attachment_index}#{File.extname(attachment_filename)}"
	end

	# サムネイルのデフォルトのパスを取得します。
	def get_thumbnail_default_filepath(postid, dateCreated, attachment_index, attachment_filename)
		return "#{@thumbnail_root_path}#{postid}_#{attachment_index}#{File.extname(attachment_filename)}"
	end

	# ブログ記事投稿用のプラグインを取得します。
	def get_post_plugin()
		return WordPressPost_WeblogPlugin.new(self)
	end

	# ブログ記事編集用のプラグインを取得します。
	def get_edit_plugin()
		return WordPressEdit_WeblogPlugin.new(self)
	end

end
